package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Mar 29, 2025
License: GPL-3.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Handlers maps command names to their implementations.
Help command: Displays documentation for all or a specific command.
RegisterCommand registers a command function with its documentation.
type Command ¶
added in
v0.0.3
Command represents a command with an associated function and documentation.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.